==> open-cluster-management-observability-model-6.4.0-sources.jar: io/fabric8/openclustermanagement/api/model/multiclusterobservabilityoperator/apps/v1beta2/RetentionConfigFluentImpl.java <==
package io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class RetentionConfigFluentImpl<A extends RetentionConfigFluent<A>> extends BaseFluent<A> implements RetentionConfigFluent<A>{
  public RetentionConfigFluentImpl() {
  }
  public RetentionConfigFluentImpl(RetentionConfig instance) {
    this.withBlockDuration(instance.getBlockDuration()); 
    this.withDeleteDelay(instance.getDeleteDelay()); 
    this.withRetentionInLocal(instance.getRetentionInLocal()); 
    this.withRetentionResolution1h(instance.getRetentionResolution1h()); 
    this.withRetentionResolution5m(instance.getRetentionResolution5m()); 
    this.withRetentionResolutionRaw(instance.getRetentionResolutionRaw()); 
  }
  private String blockDuration;
  private String deleteDelay;
  private String retentionInLocal;
  private String retentionResolution1h;
  private String retentionResolution5m;
  private String retentionResolutionRaw;
  public String getBlockDuration() {
    return this.blockDuration;
  }
  public A withBlockDuration(String blockDuration) {
    this.blockDuration=blockDuration; return (A) this;
  }
  public Boolean hasBlockDuration() {
    return this.blockDuration != null;
  }
  public String getDeleteDelay() {
    return this.deleteDelay;
  }
  public A withDeleteDelay(String deleteDelay) {
    this.deleteDelay=deleteDelay; return (A) this;
  }
  public Boolean hasDeleteDelay() {
    return this.deleteDelay != null;
  }
  public String getRetentionInLocal() {
    return this.retentionInLocal;
  }
  public A withRetentionInLocal(String retentionInLocal) {
    this.retentionInLocal=retentionInLocal; return (A) this;
  }
  public Boolean hasRetentionInLocal() {
    return this.retentionInLocal != null;
  }
  public String getRetentionResolution1h() {
    return this.retentionResolution1h;
  }
  public A withRetentionResolution1h(String retentionResolution1h) {
    this.retentionResolution1h=retentionResolution1h; return (A) this;
  }
  public Boolean hasRetentionResolution1h() {
    return this.retentionResolution1h != null;
  }
  public String getRetentionResolution5m() {
    return this.retentionResolution5m;
  }
  public A withRetentionResolution5m(String retentionResolution5m) {
    this.retentionResolution5m=retentionResolution5m; return (A) this;
  }
  public Boolean hasRetentionResolution5m() {
    return this.retentionResolution5m != null;
  }
  public String getRetentionResolutionRaw() {
    return this.retentionResolutionRaw;
  }
  public A withRetentionResolutionRaw(String retentionResolutionRaw) {
    this.retentionResolutionRaw=retentionResolutionRaw; return (A) this;
  }
  public Boolean hasRetentionResolutionRaw() {
    return this.retentionResolutionRaw != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    RetentionConfigFluentImpl that = (RetentionConfigFluentImpl) o;
    if (blockDuration != null ? !blockDuration.equals(that.blockDuration) :that.blockDuration != null) return false;
    if (deleteDelay != null ? !deleteDelay.equals(that.deleteDelay) :that.deleteDelay != null) return false;
    if (retentionInLocal != null ? !retentionInLocal.equals(that.retentionInLocal) :that.retentionInLocal != null) return false;
    if (retentionResolution1h != null ? !retentionResolution1h.equals(that.retentionResolution1h) :that.retentionResolution1h != null) return false;
    if (retentionResolution5m != null ? !retentionResolution5m.equals(that.retentionResolution5m) :that.retentionResolution5m != null) return false;
    if (retentionResolutionRaw != null ? !retentionResolutionRaw.equals(that.retentionResolutionRaw) :that.retentionResolutionRaw != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(blockDuration,  deleteDelay,  retentionInLocal,  retentionResolution1h,  retentionResolution5m,  retentionResolutionRaw,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (blockDuration != null) { sb.append("blockDuration:"); sb.append(blockDuration + ","); }
    if (deleteDelay != null) { sb.append("deleteDelay:"); sb.append(deleteDelay + ","); }
    if (retentionInLocal != null) { sb.append("retentionInLocal:"); sb.append(retentionInLocal + ","); }
    if (retentionResolution1h != null) { sb.append("retentionResolution1h:"); sb.append(retentionResolution1h + ","); }
    if (retentionResolution5m != null) { sb.append("retentionResolution5m:"); sb.append(retentionResolution5m + ","); }
    if (retentionResolutionRaw != null) { sb.append("retentionResolutionRaw:"); sb.append(retentionResolutionRaw); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> open-cluster-management-observability-model-6.7.1-sources.jar: io/fabric8/openclustermanagement/api/model/multiclusterobservabilityoperator/apps/v1beta2/RetentionConfigFluentImpl.java <==
package io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class RetentionConfigFluentImpl<A extends RetentionConfigFluent<A>> extends BaseFluent<A> implements RetentionConfigFluent<A>{
  public RetentionConfigFluentImpl() {
  }
  public RetentionConfigFluentImpl(RetentionConfig instance) {
    if (instance != null) {
      this.withBlockDuration(instance.getBlockDuration());
      this.withDeleteDelay(instance.getDeleteDelay());
      this.withRetentionInLocal(instance.getRetentionInLocal());
      this.withRetentionResolution1h(instance.getRetentionResolution1h());
      this.withRetentionResolution5m(instance.getRetentionResolution5m());
      this.withRetentionResolutionRaw(instance.getRetentionResolutionRaw());
    }
  }
  private String blockDuration;
  private String deleteDelay;
  private String retentionInLocal;
  private String retentionResolution1h;
  private String retentionResolution5m;
  private String retentionResolutionRaw;
  public String getBlockDuration() {
    return this.blockDuration;
  }
  public A withBlockDuration(String blockDuration) {
    this.blockDuration=blockDuration; return (A) this;
  }
  public Boolean hasBlockDuration() {
    return this.blockDuration != null;
  }
  public String getDeleteDelay() {
    return this.deleteDelay;
  }
  public A withDeleteDelay(String deleteDelay) {
    this.deleteDelay=deleteDelay; return (A) this;
  }
  public Boolean hasDeleteDelay() {
    return this.deleteDelay != null;
  }
  public String getRetentionInLocal() {
    return this.retentionInLocal;
  }
  public A withRetentionInLocal(String retentionInLocal) {
    this.retentionInLocal=retentionInLocal; return (A) this;
  }
  public Boolean hasRetentionInLocal() {
    return this.retentionInLocal != null;
  }
  public String getRetentionResolution1h() {
    return this.retentionResolution1h;
  }
  public A withRetentionResolution1h(String retentionResolution1h) {
    this.retentionResolution1h=retentionResolution1h; return (A) this;
  }
  public Boolean hasRetentionResolution1h() {
    return this.retentionResolution1h != null;
  }
  public String getRetentionResolution5m() {
    return this.retentionResolution5m;
  }
  public A withRetentionResolution5m(String retentionResolution5m) {
    this.retentionResolution5m=retentionResolution5m; return (A) this;
  }
  public Boolean hasRetentionResolution5m() {
    return this.retentionResolution5m != null;
  }
  public String getRetentionResolutionRaw() {
    return this.retentionResolutionRaw;
  }
  public A withRetentionResolutionRaw(String retentionResolutionRaw) {
    this.retentionResolutionRaw=retentionResolutionRaw; return (A) this;
  }
  public Boolean hasRetentionResolutionRaw() {
    return this.retentionResolutionRaw != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    RetentionConfigFluentImpl that = (RetentionConfigFluentImpl) o;
    if (!java.util.Objects.equals(blockDuration, that.blockDuration)) return false;

    if (!java.util.Objects.equals(deleteDelay, that.deleteDelay)) return false;

    if (!java.util.Objects.equals(retentionInLocal, that.retentionInLocal)) return false;

    if (!java.util.Objects.equals(retentionResolution1h, that.retentionResolution1h)) return false;

    if (!java.util.Objects.equals(retentionResolution5m, that.retentionResolution5m)) return false;

    if (!java.util.Objects.equals(retentionResolutionRaw, that.retentionResolutionRaw)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(blockDuration,  deleteDelay,  retentionInLocal,  retentionResolution1h,  retentionResolution5m,  retentionResolutionRaw,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (blockDuration != null) { sb.append("blockDuration:"); sb.append(blockDuration + ","); }
    if (deleteDelay != null) { sb.append("deleteDelay:"); sb.append(deleteDelay + ","); }
    if (retentionInLocal != null) { sb.append("retentionInLocal:"); sb.append(retentionInLocal + ","); }
    if (retentionResolution1h != null) { sb.append("retentionResolution1h:"); sb.append(retentionResolution1h + ","); }
    if (retentionResolution5m != null) { sb.append("retentionResolution5m:"); sb.append(retentionResolution5m + ","); }
    if (retentionResolutionRaw != null) { sb.append("retentionResolutionRaw:"); sb.append(retentionResolutionRaw); }
    sb.append("}");
    return sb.toString();
  }
  
}
